@@ -6,8 +6,13 @@ import itertools
 
 import pytest
 
-from pathvalidate import ascii_symbols, replace_symbol, unprintable_ascii_chars, validate_symbol
-from pathvalidate._symbol import replace_unprintable, validate_unprintable
+from pathvalidate import (
+    ascii_symbols,
+    replace_symbol,
+    unprintable_ascii_chars,
+    validate_symbol,
+    validate_unprintable_char,
+)
 from pathvalidate.error import ErrorReason, ValidationError
 
 from ._common import alphanum_chars
@@ -96,14 +101,19 @@ class Test_replace_symbol:
         )
 
     @pytest.mark.parametrize(
-        ["value", "expected"], [[None, TypeError], [1, TypeError], [True, TypeError]]
+        ["value", "expected"],
+        [
+            [None, TypeError],
+            [1, TypeError],
+            [True, TypeError],
+        ],
     )
     def test_abnormal(self, value, expected):
         with pytest.raises(expected):
             replace_symbol(value)
 
 
-class Test_validate_unprintable:
+class Test_validate_unprintable_char:
     VALID_CHARS = alphanum_chars
     INVALID_CHARS = unprintable_ascii_chars
 
@@ -111,13 +121,13 @@ class Test_validate_unprintable:
         ["value"], [["abc" + valid_char + "hoge123"] for valid_char in VALID_CHARS]
     )
     def test_normal(self, value):
-        validate_unprintable(value)
+        validate_unprintable_char(value)
 
     @pytest.mark.parametrize(["value"], [["あいうえお"], ["シート"]])
     def test_normal_multibyte(self, value):
         pytest.skip("TODO")
 
-        validate_unprintable(value)
+        validate_unprintable_char(value)
 
     @pytest.mark.parametrize(
         ["value"],
@@ -128,33 +138,5 @@ class Test_validate_unprintable:
     )
     def test_exception_invalid_char(self, value):
         with pytest.raises(ValidationError) as e:
-            validate_unprintable(value)
+            validate_unprintable_char(value)
         assert e.value.reason == ErrorReason.INVALID_CHARACTER
-
-
-class Test_replace_unprintable:
-    TARGET_CHARS = unprintable_ascii_chars
-    NOT_TARGET_CHARS = alphanum_chars
-    REPLACE_TEXT_LIST = ["", "_"]
-
-    @pytest.mark.parametrize(
-        ["value", "replace_text", "expected"],
-        [
-            ["A" + c + "B", rep, "A" + rep + "B"]
-            for c, rep in itertools.product(TARGET_CHARS, REPLACE_TEXT_LIST)
-        ]
-        + [
-            ["A" + c + "B", rep, "A" + c + "B"]
-            for c, rep in itertools.product(NOT_TARGET_CHARS, REPLACE_TEXT_LIST)
-        ]
-        + [["", "", ""]],
-    )
-    def test_normal(self, value, replace_text, expected):
-        assert replace_unprintable(value, replace_text) == expected
-
-    @pytest.mark.parametrize(
-        ["value", "expected"], [[None, TypeError], [1, TypeError], [True, TypeError]]
-    )
-    def test_abnormal(self, value, expected):
-        with pytest.raises(expected):
-            replace_unprintable(value)
